@@ -2,7 +2,7 @@ from pyg_base._as_float import as_float
 from pyg_base._as_list import as_list, as_tuple, first, last, passthru, unique, is_rng
 from pyg_base._acell import acell, acell_load, acell_func, acell_go
 from pyg_base._cache import cache, get_cache
-from pyg_base._cell import cell, cell_go, cell_item, cell_func, cell_load, cell_output, cell_clear, cell_inputs, GRAPH, UPDATED
+from pyg_base._cell import cell, cell_go, cell_item, cell_func, cell_load, cell_output, cell_clear, cell_inputs
 from pyg_base._cfg import mkdir, cfg_read, cfg_write, CFG
 from pyg_base._dates import dt,dt_bump, today, ymd, TMIN, TMAX, DAY, futcodes, dt2str, is_bump, nth_weekday_of_month
 from pyg_base._dag import get_DAG, get_DAGs, get_GADs, get_GAD, add_edge, topological_sort, descendants, del_edge
@@ -21,7 +21,7 @@ from pyg_base._loop import loop, loops, len0, pd2np, shape, loop_all
 from pyg_base._named_dict import named_dict
 from pyg_base._pandas import df_index, df_columns, df_reindex, np_reindex, df_concat, df_fillna, presync, df_sync, \
     add_, sub_, mul_, div_, pow_, df_slice, df_unslice, nona
-from pyg_base._parquet import pd_to_parquet, pd_read_parquet
+from pyg_base._parquet import pd_to_parquet, pd_read_parquet, pd_to_npy, pd_read_npy, np_save
 from pyg_base._perdictable import join, perdictable
 from pyg_base._reducer import reducer, reducing
 from pyg_base._sort import sort, cmp, Cmp
